ReflectiveBubblePainter constructor

const ReflectiveBubblePainter({
  1. Key? key,
  2. required PopPopBubbleTheme themeModel,
})

Creates a ReflectiveBubblePainter.

Internally calculates and paints the dimensions of an unpopped bubble from the given themeModel.size, creating a parallel reflective effect on the top layer of the bubble.

Implementation

const ReflectiveBubblePainter({
  Key? key,
  required this.themeModel,
}) : super(key: key);