ProviderBubble constructor

const ProviderBubble({
  1. Key? key,
  2. required Widget unpoppedBubble,
  3. required Widget poppedBubble,
  4. required VoidCallback onPopped,
  5. PopPopBubbleTheme bubbleTheme = const PopPopBubbleTheme(),
})

Creates a Provider-based bubble, encapsulating ChangeNotifierProvider .

ChangeNotifier is automatically handled and disposed of when the bubble no longer exists with the game grid (such as when the ListView.builder has scrolled down).

Implementation

const ProviderBubble({
  Key? key,
  required this.unpoppedBubble,
  required this.poppedBubble,
  required this.onPopped,
  this.bubbleTheme = const PopPopBubbleTheme(),
}) : super(key: key);