ProviderBubble constructor
const
ProviderBubble({
- Key? key,
- required Widget unpoppedBubble,
- required Widget poppedBubble,
- required VoidCallback onPopped,
- PopPopBubbleTheme bubbleTheme = const PopPopBubbleTheme(),
Creates a Provider-based bubble, encapsulating ChangeNotifierProvider .
ChangeNotifier is automatically handled and disposed of when the bubble no longer exists with the game grid (such as when the ListView.builder has scrolled down).
Implementation
const ProviderBubble({
Key? key,
required this.unpoppedBubble,
required this.poppedBubble,
required this.onPopped,
this.bubbleTheme = const PopPopBubbleTheme(),
}) : super(key: key);